import React, { useState } from "react";
import { apiCall } from "../api/apiClient";

interface RegisterProps {
  onSwitchToLogin: () => void;
  isDarkMode: boolean;
}

export const Register: React.FC<RegisterProps> = ({ 
  onSwitchToLogin, 
  isDarkMode 
}) => {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [error, setError] = useState<string | null>(null);
  const [loading, setLoading] = useState(false);
  const [success, setSuccess] = useState(false);

  async function handleSubmit(e: React.FormEvent) {
    e.preventDefault();
    setLoading(true);
    setError(null);
    setSuccess(false);

    try {
      const res = await apiCall("/api/register", {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ username, password }),
      });

      if (!res.ok) {
        const errorText = await res.text();
        throw new Error(`Registration failed: ${res.status} ${res.statusText} - ${errorText}`);
      }

      setSuccess(true);
      setTimeout(() => {
        onSwitchToLogin();
      }, 2000);
    } catch (err: any) {
      setError(err.message || "Unknown error");
    } finally {
      setLoading(false);
    }
  }

  return (
    <div className={`gradient-bg ${isDarkMode ? 'gradient-bg-dark' : 'gradient-bg-light'}`}>
      <div
        className={`auth-container ${
          isDarkMode ? 'auth-container-dark' : 'auth-container-light'
        }`}
      >
        <h2 className={`auth-title ${isDarkMode ? 'text-white' : 'text-gray-900'}`}>
          Register
        </h2>

        {error && (
          <div className="error-message">
            {error}
          </div>
        )}

        {success && (
          <div className="success-message">
            Registration successful! Redirecting to login...
          </div>
        )}

        <form onSubmit={handleSubmit} className="auth-form">
          <input
            type="text"
            placeholder="Username"
            value={username}
            onChange={(e) => setUsername(e.target.value)}
            className={`auth-input ${
              isDarkMode ? 'auth-input-dark' : 'auth-input-light'
            }`}
            required
          />
          
          <input
            type="password"
            placeholder="Password"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
            className={`auth-input ${
              isDarkMode ? 'auth-input-dark' : 'auth-input-light'
            }`}
            required
          />

          <button
            type="submit"
            disabled={loading}
            className={`auth-button ${
              isDarkMode ? 'auth-button-dark' : 'auth-button-light'
            }`}
          >
            {loading ? "Registering..." : "Register"}
          </button>
        </form>

        <button
          type="button"
          onClick={onSwitchToLogin}
          className={`auth-switch ${
            isDarkMode ? 'auth-switch-dark' : 'auth-switch-light'
          }`}
        >
          Already have an account? Login now
        </button>
      </div>
    </div>
  );
};