import React from "react";
import {Palette} from "lucide-react";

interface GradientColors {
  dark: { from: string; to: string };
  light: { from: string; to: string };
}

interface SettingsComponentProps {
  isDarkMode: boolean;
  onThemeToggle: () => void;
  gradientColors: GradientColors;
  setGradientColors: React.Dispatch<React.SetStateAction<GradientColors>>;
}

export const SettingsComponent: React.FC<SettingsComponentProps> = ({
  isDarkMode,
  gradientColors,
  setGradientColors
}) => {
  const ColorPicker: React.FC<{ 
    label: string; 
    value: string; 
    onChange: (value: string) => void 
  }> = ({ label, value, onChange }) => (
    <div className="color-picker-container">
      <span className={`color-picker-label ${isDarkMode ? 'text-gray-300' : 'text-gray-600'}`}>
        {label}
      </span>
      <input
        type="color"
        value={value}
        onChange={(e) => onChange(e.target.value)}
        className="color-picker-input"
      />
    </div>
  );

  return (
    <div className="component-container">
      <div className="component-header">
        <h1 className={`component-title ${isDarkMode ? 'text-white' : 'text-gray-800'}`}>
          Settings
        </h1>
      </div>

      <div className="settings-content">
        {/* Gradient Colors */}
        <div className={`gradient-settings ${
          isDarkMode ? 'gradient-settings-dark' : 'gradient-settings-light'
        }`}>
          <h3 className={`gradient-settings-title ${
            isDarkMode ? 'text-white' : 'text-gray-800'
          }`}>
            <Palette size={18} />
            Gradient Colors
          </h3>
          
          <div className="gradient-settings-content">
            <div className="gradient-group">
              <h4 className={`gradient-group-title ${
                isDarkMode ? 'text-gray-300' : 'text-gray-600'
              }`}>
                Dark Mode Gradient
              </h4>
              <div className="gradient-controls">
                <ColorPicker
                  label="From"
                  value={gradientColors.dark.from}
                  onChange={(value) => setGradientColors(prev => ({
                    ...prev,
                    dark: { ...prev.dark, from: value }
                  }))}
                />
                <ColorPicker
                  label="To"
                  value={gradientColors.dark.to}
                  onChange={(value) => setGradientColors(prev => ({
                    ...prev,
                    dark: { ...prev.dark, to: value }
                  }))}
                />
              </div>
              <div 
                className="gradient-preview"
                style={{
                  background: `linear-gradient(135deg, ${gradientColors.dark.from} 0%, ${gradientColors.dark.to} 100%)`
                }}
              />
            </div>
            
            <div className="gradient-group">
              <h4 className={`gradient-group-title ${
                isDarkMode ? 'text-gray-300' : 'text-gray-600'
              }`}>
                Light Mode Gradient
              </h4>
              <div className="gradient-controls">
                <ColorPicker
                  label="From"
                  value={gradientColors.light.from}
                  onChange={(value) => setGradientColors(prev => ({
                    ...prev,
                    light: { ...prev.light, from: value }
                  }))}
                />
                <ColorPicker
                  label="To"
                  value={gradientColors.light.to}
                  onChange={(value) => setGradientColors(prev => ({
                    ...prev,
                    light: { ...prev.light, to: value }
                  }))}
                />
              </div>
              <div 
                className="gradient-preview"
                style={{
                  background: `linear-gradient(135deg, ${gradientColors.light.from} 0%, ${gradientColors.light.to} 100%)`
                }}
              />
            </div>
          </div>
        </div>

        {/* Additional Settings Placeholder */}
        <div className={`settings-section ${
          isDarkMode ? 'settings-section-dark' : 'settings-section-light'
        }`}>
          <h3 className={`settings-section-title ${
            isDarkMode ? 'text-white' : 'text-gray-800'
          }`}>
            Coming Soon
          </h3>
          <p className={`settings-section-description ${
            isDarkMode ? 'text-gray-400' : 'text-gray-500'
          }`}>
            More settings will be available in future updates, including file management preferences, 
            notification settings, and account management options.
          </p>
        </div>
      </div>
    </div>
  );
};