import React, { useState, useEffect } from "react";
import { Trash2 } from "lucide-react";
import { apiCall } from "../api/apiClient";

interface ShareInfo {
  id: string;
  file_id: number;
  file_name: string;
  created_at: string;
  expires_at: string | null;
  is_expired: boolean;
}

interface SharesComponentProps {
  isDarkMode: boolean;
}

export const SharesComponent: React.FC<SharesComponentProps> = ({ isDarkMode }) => {
  const [shares, setShares] = useState<ShareInfo[]>([]);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const [success, setSuccess] = useState<string | null>(null);

  const fetchShares = async () => {
    try {
      setLoading(true);
      setError(null);
      const response = await apiCall('/api/shares');
      const sharesData = await response.json();
      setShares(sharesData);
    } catch (err) {
      setError('Failed to fetch shares');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchShares();
  }, []);

  const handleDeleteShare = async (shareId: string) => {
    try {
      setLoading(true);
      setError(null);
      await apiCall(`/api/shares/${shareId}`, {
        method: 'DELETE',
      });
      setSuccess('Share deleted successfully');
      fetchShares();
    } catch (err) {
      setError('Failed to delete share');
    } finally {
      setLoading(false);
    }
  };

  const handleDownload = async (share: ShareInfo) => {
    try {
      setLoading(true);
      setError(null);
      const response = await fetch(`/api/shared/${share.id}`);
      if (!response.ok) throw new Error('Download failed');
      const blob = await response.blob();
      const url = window.URL.createObjectURL(blob);
      const a = document.createElement('a');
      a.href = url;
      a.download = share.file_name;
      document.body.appendChild(a);
      a.click();
      a.remove();
      window.URL.revokeObjectURL(url);
    } catch (err) {
      setError('Failed to download file');
    } finally {
      setLoading(false);
    }
  };

  const formatDate = (dateString: string | null) => {
    if (!dateString) return '-';
    return new Date(dateString).toLocaleString();
  };

  const copyToClipboard = async (shareId: string) => {
    try {
      const shareUrl = `${window.location.origin}/api/shared/${shareId}`;
      await navigator.clipboard.writeText(shareUrl);
      setSuccess('Share link copied to clipboard!');
    } catch (err) {
      setError('Failed to copy link');
    }
  };

  return (
    <div className="component-container">
      {/* Success/Error Messages */}
      {error && (
        <div className="notification notification-error">
          {error}
          <button onClick={() => setError(null)} className="notification-close">×</button>
        </div>
      )}
      {success && (
        <div className="notification notification-success">
          {success}
          <button onClick={() => setSuccess(null)} className="notification-close">×</button>
        </div>
      )}

      <div className="component-header">
        <h1 className={`component-title ${isDarkMode ? 'text-white' : 'text-gray-800'}`}>Shared Files</h1>
      </div>

      {loading && (
        <div className="loading-center">
          <div className="loading-spinner-small"></div>
        </div>
      )}

      <div className={`table-container ${isDarkMode ? 'table-container-dark' : 'table-container-light'}`}> 
        <table className="data-table full-width-table">
          <thead className={isDarkMode ? 'table-header-dark' : 'table-header-light'}>
            <tr>
              <th className="table-header-cell">Name</th>
              <th className="table-header-cell">Created</th>
              <th className="table-header-cell">Expires</th>
              <th className="table-header-cell">Link</th>
              <th className="table-header-cell actions-header-cell"></th>
            </tr>
          </thead>
          <tbody className={`table-body ${isDarkMode ? 'table-body-dark' : 'table-body-light'}`}> 
            {shares.map((share) => (
              <tr key={share.id} className={isDarkMode ? 'table-row-dark' : 'table-row-light'}>
                <td
                  className={`table-cell ${isDarkMode ? 'text-white' : 'text-gray-900'}`}
                  style={{ cursor: share.is_expired ? 'not-allowed' : 'pointer', textDecoration: 'underline' }}
                  onClick={() => !share.is_expired && handleDownload(share)}
                  title={share.is_expired ? 'Expired' : 'Download shared file'}
                >
                  {share.file_name}
                </td>
                <td className={`table-cell ${isDarkMode ? 'text-gray-300' : 'text-gray-500'}`}>{formatDate(share.created_at)}</td>
                <td className={`table-cell ${share.is_expired ? 'text-red-500' : isDarkMode ? 'text-gray-300' : 'text-gray-500'}`}>{share.expires_at ? (share.is_expired ? 'Expired' : formatDate(share.expires_at)) : '-'}</td>
                <td className={`table-cell ${isDarkMode ? 'text-gray-300' : 'text-gray-500'}`}> 
                  <button
                    onClick={() => copyToClipboard(share.id)}
                    className={`share-link ${isDarkMode ? 'share-link-dark' : 'share-link-light'}`}
                    title="Copy share link"
                  >
                    /api/shared/{share.id.substring(0, 8)}...
                  </button>
                </td>
                <td className="table-cell actions-cell">
                  <button
                    onClick={() => handleDeleteShare(share.id)}
                    className="dropdown-item dropdown-item-danger"
                    title="Delete share"
                  >
                    <Trash2 size={16} />
                  </button>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
        {shares.length === 0 && !loading && (
          <div className={`empty-state ${isDarkMode ? 'text-gray-400' : 'text-gray-500'}`}>No shared files yet</div>
        )}
      </div>
    </div>
  );
};